create table test1 (
    id INTEGER PRIMARY KEY,
    something TEXT -- test1
);

-- test2
-- test3
create table test2 (
    id INTEGER PRIMARY KEY, -- test4
    -- test5
    something TEXT
);
